@@ -16,11 +16,11 @@ Struct::Path::PerlStyle - Perl-style syntax frontend for L<Struct::Path|Struct::
 
 =head1 VERSION
 
-Version 0.24
+Version 0.31
 
 =cut
 
-our $VERSION = '0.24';
+our $VERSION = '0.31';
 
 =head1 SYNOPSIS
 
@@ -51,9 +51,17 @@ Path syntax examples:
     "{a}{b}[0,1,2,5]"     # 0, 1, 2 and 5 array's items
     "{a}{b}[0..2,5]"      # same, but using ranges
     "{a}{b}[9..0]"        # descending ranges allowed (perl doesn't)
+    "{a}{b}<{c}"          # step back (perl incompatible)
 
 =cut
 
+our $OPERATORS = {
+    '<' => sub {
+        pop @{$_[0]};
+        pop @{$_[1]}
+    },
+};
+
 sub ps_parse($) {
     my $path = shift;
     croak "Undefined path passed" unless (defined $path);
@@ -108,6 +116,8 @@ sub ps_parse($) {
                     }
                 }
                 croak "Unfinished range secified (step #$sc)" if ($is_range);
+            } elsif ($item->isa('PPI::Token::Operator') and exists $OPERATORS->{$item->content}) {
+                push @{$out}, $OPERATORS->{$item->content};
             } else {
                 croak "Unsupported thing '" . $item->content . "' in the path (step #$sc)" ;
             }
@@ -123,6 +133,7 @@ sub ps_parse($) {
 Serialize L<Struct::Path|Struct::Path> path to perl-style string
 
     $string = ps_serialize($struct_path);
+    @steps = ps_serialize($struct_path);  # list of serialized steps in list context
 
 =cut
 
@@ -130,7 +141,7 @@ sub ps_serialize($) {
     my $path = shift;
     croak "Path must be an arrayref" unless (ref $path eq 'ARRAY');
 
-    my $out = '';
+    my @out;
     my $sc = 0; # step counter
 
     for my $step (@{$path}) {
@@ -148,7 +159,7 @@ sub ps_serialize($) {
                     push @ranges, [$i, $i];
                 }
             }
-            $out .= "[" . join(",", map { $_->[0] != $_->[1] ? "$_->[0]..$_->[1]" : $_->[0] } @{ranges}) . "]";
+            push @out, "[" . join(",", map { $_->[0] != $_->[1] ? "$_->[0]..$_->[1]" : $_->[0] } @{ranges}) . "]";
         } elsif (ref $step eq 'HASH') {
             my @items;
             if (keys %{$step} == 1 and exists $step->{keys} and ref $step->{keys} eq 'ARRAY' or not keys %{$step}) {
@@ -156,14 +167,14 @@ sub ps_serialize($) {
             } else {
                 croak "Unsupported hash definition (step #$sc)";
             }
-            $out .= "{" . join(",", @items) . "}";
+            push @out, "{" . join(",", @items) . "}";
         } else {
             croak "Unsupported thing in the path (step #$sc)";
         }
         $sc++;
     }
 
-    return $out;
+    return wantarray ? @out : join('', @out);
 }
 
 =head1 AUTHOR
